
from setuptools import setup, find_packages

setup(
    name="orange1-mcp-tool-builder",
    version="None",
    description="MCP server for dynamic tool creation",
    author="orange1",
    author_email="support@orange.ai",
    url="",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
    install_requires=['mcp', 'anthropic', 'python-dotenv', 'requests>=2.32.3', 'geopy'],
    keywords=["orange1"] + [],
)
